#!/bin/sh
prefix=/usr/share
infodir=${prefix}/info
cd ${infodir}
for fn in gnugo.info ; do
  install-info --dir-file=./dir --info-file=${fn}
done
